"""Supplies all subcommands available via `axii self`."""

import rich_click as click

from armarx_setup.cli import common
from armarx_setup.cli.self import integration
from armarx_setup.core.config import config as axii_config

COMMAND_GROUPS = []  # Default.


@click.group(**common.group_kwargs)
def self():
    """Interact with Axii itself."""


@self.command("install", **common.command_kwargs)
@click.option("--auto-detect/--no-auto-detect", is_flag=True, default=True,
              help="Install and auto-detect shell from $SHELL.")
@click.option("--zsh", is_flag=True, default=False, help="Install for zsh.")
@click.option("--bash", is_flag=True, default=False, help="Install for bash.")
@click.option("--yes", is_flag=True, default=False,
              help="Do not ask for confirmation for installing.")
def self_install(**kwargs):
    """Install Axii in your shell."""

    common.bootstrap(ensure_installation=False, print_logo=True)

    integration.install(**kwargs)


@self.command("update", **common.command_kwargs)
@click.option("--only-check", is_flag=True, default=False,
              help="Only check if updates are available, but do nothing.")
def self_update(**kwargs):
    """Update Axii itself."""

    common.bootstrap(ensure_installation=True, print_logo=True)

    integration.update(**kwargs)


@self.command("change-release", **common.command_kwargs)
@click.argument("release-channel")
def self_change_release(**kwargs):
    """Change Axii's release channel."""

    # Don't print logo here but after switching the branch.
    common.bootstrap(ensure_installation=True, print_logo=False)

    integration.change_release(**kwargs)


@self.command("report", **common.command_kwargs)
def self_report(**kwargs):
    """Dump a self report for use in issues or for debugging."""

    common.bootstrap(ensure_installation=False, print_logo=False)

    integration.report(**kwargs)


if axii_config.get("dev_mode"):
    @self.group("maintain", **common.group_kwargs)
    def self_maintain():
        """Tools for Axii maintenance."""


    @self_maintain.command("release", **common.command_kwargs)
    def self_maintain_release(**kwargs):
        """Creates a new release from local main branch."""

        common.bootstrap(ensure_installation=True, print_logo=True)

        integration.release(**kwargs)
