import enum
import os
import re
import subprocess

from armarx_setup import PACKAGE_ROOT
from armarx_setup.core.util import commands
from armarx_setup.core.config import config as axii_config


class SelfUpdateStatus(enum.Enum):
    UP_TO_DATE = enum.auto()
    OUTDATED = enum.auto()


def check_for_updates() -> SelfUpdateStatus:
    out = commands.run('git fetch origin ; git status', cwd=PACKAGE_ROOT, capture_output=True,
                       quiet=True)
    if re.search(r"Your branch is up to date with '.*'\.", out) is not None:
        return SelfUpdateStatus.UP_TO_DATE
    elif re.search(r"Your branch is behind '.*' by [0-9]+ commits?, and can be fast-forwarded\.",
                   out) is not None:
        return SelfUpdateStatus.OUTDATED


def update():
    commands.run('git pull', cwd=PACKAGE_ROOT)


def find_venv() -> str:
    from armarx_setup import PACKAGE_ROOT

    os_codename = axii_config.get_os_codename()

    for directory in [f".venv_{os_codename}", ".venv", "venv"]:
        venv = os.path.join(PACKAGE_ROOT, directory)
        if os.path.isdir(venv):
            return venv

    return ""


def update_venv():
    console = axii_config.console

    venv_dir = find_venv()
    if venv_dir:
        python = os.path.join(venv_dir, "bin", "python")
        requirements = os.path.join(PACKAGE_ROOT, "requirements.txt")

        console.print(f"Updating virtual environment '{venv_dir}'.")
        r = subprocess.run(f"{python} -m pip install --upgrade pip", shell=True,
                           stdout=subprocess.PIPE)
        if r.returncode != 0:
            console.print("Failed to update pip.")
            return

        r = subprocess.run(f"{python} -m pip install --upgrade -r {requirements}", shell=True,
                           stdout=subprocess.PIPE)
        if r.returncode == 0:
            console.print("Updated environment.")
            return True
        else:
            console.print("Failed to update environment.")
            return False
    else:
        console.print("Could not find virtual environment.")
        return False
