import hashlib
import json
import os.path
import sys


def md5(string):
    return hashlib.md5(string.encode("utf-8")).hexdigest()


def main():
    reports = []

    if len(sys.argv) <= 1:
        print("Usage: python lint_markdown.py [MARKDOWN_FILE]")
        sys.exit(1)

    lint_file = sys.argv[1]

    assert os.path.isfile(lint_file)

    with open(lint_file, encoding="utf-8") as file:
        for line in file:
            line = line.strip()

            path, line_no, _column_no, description = line.split(":", maxsplit=3)
            line_no = int(line_no)
            description = description.strip()

            report = {
                "description": description,
                "fingerprint": md5(path + description),
                "severity": "minor",
                "location": {
                    "path": path,
                    "lines": {
                        "begin": line_no
                    }
                }
            }

            reports.append(report)

    print(json.dumps(reports, indent=2))


if __name__ == "__main__":
    main()
