"""
Tests `axii config` functionalities.
"""

import os
import pytest

from armarx_setup.core import error
from armarx_setup.core.config import axii_config as axii_config_raw
from armarx_setup.core.util.commands import run
from armarx_setup.core.workspace import Workspace

from tests.e2e import cmd_args, test_workspace


variable_name = "e2e_test_var"
nested_variable_prefix = "e2e"
nested_variable_name = "test_var"
variable_value = "true"


@pytest.fixture()
def axii_config():
    """Injecting this fixture will ensure that the actual global config is backed up and restored for e2e tests."""

    axii_config_raw.create_global_config_backup()
    yield axii_config_raw
    axii_config_raw.restore_global_config_backup()


def test_get_nonexistent_global_config_var(axii_config):
    """
    Test getting non-existent global config variable.
    """

    try:
        run(f"axii config --global {variable_name}", **cmd_args)
    except error.CommandFailed as e:
        stdout = e.stdout
        return_code = e.return_code
    else:
        stdout = ""
        return_code = 0

    assert return_code == 1, "Return code should be 1."
    assert f"No such config variable '{variable_name}'." in stdout


def test_set_and_get_global_config_var(axii_config):
    """
    Test setting and getting global config variable.
    """

    stdout = run(f"axii config --global {variable_name} {variable_value}", **cmd_args)

    assert stdout == f"Set '{variable_name}' (global) to {variable_value}."

    stdout = run(f"axii config --global {variable_name}", **cmd_args)

    assert stdout == "true"


def test_unset_global_config_var(axii_config):
    """
    Test unsetting global config variable.
    """

    stdout = run(f"axii config --global {variable_name} {variable_value}", **cmd_args)

    assert stdout == f"Set '{variable_name}' (global) to {variable_value}."

    stdout = run(f"axii config --global --unset {variable_name}", **cmd_args)

    assert stdout == f"Unset '{variable_name}' (global)."
